@@ -12,7 +12,7 @@ use warnings;
 
 =head1 NAME
 
-A - application
+C<A> - Application
 
 =head1 SYNOPSIS
 
