@@ -24,7 +24,7 @@ sub AUTOLOAD { shift; print STDERR @_ }
 
 =head1 NAME
 
-L - logging
+C<L> - logging
 
 
 =head1 SYNOPSIS
