@@ -12,7 +12,7 @@ use warnings;
 
 =head1 NAME
 
-S - singleton namespace
+C<S> - singleton namespace
 
 =head1 SYNOPSIS
 
@@ -20,7 +20,7 @@ S - singleton namespace
 
 =head1 DESCRIPTION
 
-S is an intentionally empty module. It provides a unique namespace that can
+C<S> is an intentionally empty module. It provides a unique namespace that can
 be used as a singleton holder for globals or state shared across the
 application.
 
