@@ -40,7 +40,7 @@ sub new {
 	$_ =  shift   or return undef; # Return undef  if we get false value
 
 	ref $_        &&  return $_;
-	m/^\d+$/      &&  return _sd( DateTime->from_epoch( epoch =>  $_ ) );
+	m/^[\d.]+$/   &&  return _sd( DateTime->from_epoch( epoch =>  $_ ) ); # Test float 6 and 9
 
 	return eval{ _sd( DateTime::Format::Pg->parse_datetime( $_ ) ) }; #Test: What is parsed string was with TZ?
 }
@@ -57,6 +57,7 @@ sub tmonth { (new @_  or return undef)->clone->truncate( to =>  'month' ) }
 sub tyear  { (new @_  or return undef)->clone->truncate( to =>  'year'  ) }
 
 sub next;
+sub nhour  { T::next +(new @_?shift:()  or return undef), hours  =>  shift }
 sub nday   { T::next +(new @_?shift:()  or return undef), days   =>  shift }
 sub nmonth { T::next +(new @_?shift:()  or return undef), months =>  shift }
 sub nyear  { T::next +(new @_?shift:()  or return undef), years  =>  shift }
@@ -79,9 +80,9 @@ sub fdmy { my $d =  $_[1] //'.'; fmt "%d$d%m$d%Y", new @_? shift : () }
 
 sub fd   { fmt '%Y-%m-%d',  new @_ }
 sub ft   { fmt '%H:%M:%S',  new @_ }
-sub ftm  { fmt '%T.%6N',    new @_ }
-sub fsm  { fmt '%S.%6N',    new @_ }
-sub fdtm { fmt '%F %T.%6N', new @_ }
+sub ftm  { fmt '%T.%6N',    (@_? new @_ : hnow) } # TODO: Test !.000000
+sub fsm  { fmt '%S.%6N',    (@_? new @_ : hnow) }
+sub fdtm { fmt '%F %T.%6N', (@_? new @_ : hnow) }
 
 
 
@@ -101,18 +102,28 @@ my $time =  MONOTONIC?
   sub () { Time::HiRes::clock_gettime(Time::HiRes::CLOCK_MONOTONIC()) }:
   \&Time::HiRes::time;
 
-# sub steady
+sub steady();
 {
   no strict 'refs';
   no warnings 'redefine';
-  *{T::steady} =  $time;
+  *T::steady =  $time;
 }
 
 
 
-sub diff { shift->delta_days( shift )->{ days } }
+sub diff_days { shift->delta_days( shift )->{ days } }
 
 
+my $start;
+sub start  { $start =  T::steady }
+sub diff_start {
+  DateTime->from_epoch(
+    epoch =>  ((shift //T::steady) -$start)
+  )
+}
+
+$start =  T::steady;
+
 1;
 
 =encoding utf8
@@ -159,6 +170,7 @@ T::new.
   my $dt =  T::new;                          # Defaults to T::now.
   my $dt =  T::new $dt;                      # Does nothing. Return as is.
   my $dt =  T::new 1737936005;               # DateTime from epoch.
+  my $dt =  T::new 1737936005.123457;        # DateTime from epoch with microseconds.
   my $dt =  T::new '2024-01-02 03:04:05';    # Parse string.
   my $dt =  T::new $value;
 
@@ -246,6 +258,13 @@ Return C<$value> truncated to the beginning of the year.
 
 =head1 NEXT / DATE MANIPULATION
 
+=head2 nhour
+
+  my $dt =  T::nhour $value, $hours;
+
+Add C<$hours> hours using L</next> semantics. C<$hours> can be negative.
+
+
 =head2 nday
 
   my $dt =  T::nday $value, $days;
@@ -380,12 +399,18 @@ Return a monotonic timestamp in seconds when available, otherwise
 L<Time::HiRes/time>.
 
 
-=head2 diff
+=head2 start
 
-  my $days =  T::diff $dt1, $dt2;
+  my $seconds =  T::start;
 
-Return the day delta between two L<DateTime> objects. See L<DateTime/delta_days>
-for details.
+Reset the internal stopwatch start time used by L</diff_start>.
+
+
+=head2 diff_start
+
+  my $elapsed =  T::diff_start;
+
+Return the time elapsed since the last L</start> call.
 
 
 =head1 SEE ALSO
